==> ejc-credentials-impl-3.0.0-20220518.110548-20-sources.jar: com/ejianc/certify/bean/CorpApplyBEntity.java <==
package com.ejianc.certify.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 证件借用申请-表体
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_corpcertifapply_b")
public class CorpApplyBEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="crowno")
    private Integer crowno; // 行号
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="pk_corpcertifapply")
    private Long pkCorpcertifapply; // 主表主键
    @TableField(value="pk_certiftype")
    private Long pkCertiftype; // 申请证书类别
    @TableField(value="certifnum")
    private Integer certifnum; // 证书数量
    @TableField(value="isjyyj")
    private String isjyyj; // 1-原件  2-扫描件
    @TableField(value="usage")
    private String usage; // 用途
    @TableField(value="beian_area")
    private String beianArea; // 备案区域(人力公司)
    @TableField(value="bjgw")
    private String bjgw; // 报建岗位
    @TableField(value="ismany")
    private String ismany; // 能否一证多用
    @TableField(value="isyz")
    private String isyz; // 是否需要押证
    @TableField(value="islock")
    private String islock; // 是否锁定
    @TableField(value="jydate")
    private String jydate; // 借用日期
    @TableField(value="plan_return_date")
    private String planReturnDate; // 预计归还日期
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="pjpsn")
    private String pjpsn; // 拟用证件
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; // 
    
    
    

    public Integer getCrowno() {
        return crowno;
    }

    public void setCrowno(Integer crowno) {
        this.crowno = crowno;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public Long getPkCorpcertifapply() {
        return pkCorpcertifapply;
    }

    public void setPkCorpcertifapply(Long pkCorpcertifapply) {
        this.pkCorpcertifapply = pkCorpcertifapply;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public Integer getCertifnum() {
        return certifnum;
    }

    public void setCertifnum(Integer certifnum) {
        this.certifnum = certifnum;
    }
    public String getIsjyyj() {
        return isjyyj;
    }

    public void setIsjyyj(String isjyyj) {
        this.isjyyj = isjyyj;
    }
    public String getUsage() {
        return usage;
    }

    public void setUsage(String usage) {
        this.usage = usage;
    }
    public String getBeianArea() {
        return beianArea;
    }

    public void setBeianArea(String beianArea) {
        this.beianArea = beianArea;
    }
    public String getBjgw() {
        return bjgw;
    }

    public void setBjgw(String bjgw) {
        this.bjgw = bjgw;
    }
    public String getIsmany() {
        return ismany;
    }

    public void setIsmany(String ismany) {
        this.ismany = ismany;
    }
    public String getIsyz() {
        return isyz;
    }

    public void setIsyz(String isyz) {
        this.isyz = isyz;
    }
    public String getIslock() {
        return islock;
    }

    public void setIslock(String islock) {
        this.islock = islock;
    }
    public String getJydate() {
        return jydate;
    }

    public void setJydate(String jydate) {
        this.jydate = jydate;
    }
    public String getPlanReturnDate() {
        return planReturnDate;
    }

    public void setPlanReturnDate(String planReturnDate) {
        this.planReturnDate = planReturnDate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getPjpsn() {
        return pjpsn;
    }

    public void setPjpsn(String pjpsn) {
        this.pjpsn = pjpsn;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220609.021040-45-sources.jar: com/ejianc/certify/bean/CorpApplyBEntity.java <==
package com.ejianc.certify.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 证件借用申请-表体
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_corpcertifapply_b")
public class CorpApplyBEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="crowno")
    private Integer crowno; // 行号
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="pk_corpcertifapply")
    private Long pkCorpcertifapply; // 主表主键
    @TableField(value="pk_certiftype")
    private Long pkCertiftype; // 申请证书类别
    @TableField(value="certifnum")
    private Integer certifnum; // 证书数量
    @TableField(value="isjyyj")
    private String isjyyj; // 1-原件  2-扫描件
    @TableField(value="useage")
    private String useage; // 用途
    @TableField(value="beian_area")
    private Long beianArea; // 备案区域(人力公司)
    @TableField(value="bjgw")
    private Long bjgw; // 报建岗位
    @TableField(value="ismany")
    private String ismany; // 能否一证多用
    @TableField(value="isyz")
    private String isyz; // 是否需要押证
    @TableField(value="islock")
    private String islock; // 是否锁定
    @TableField(value="jydate")
    private String jydate; // 借用日期
    @TableField(value="plan_return_date")
    private String planReturnDate; // 预计归还日期
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="pjpsn")
    private String pjpsn; // 拟用证件
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; // 
    
    
    

    public Integer getCrowno() {
        return crowno;
    }

    public void setCrowno(Integer crowno) {
        this.crowno = crowno;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public Long getPkCorpcertifapply() {
        return pkCorpcertifapply;
    }

    public void setPkCorpcertifapply(Long pkCorpcertifapply) {
        this.pkCorpcertifapply = pkCorpcertifapply;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public Integer getCertifnum() {
        return certifnum;
    }

    public void setCertifnum(Integer certifnum) {
        this.certifnum = certifnum;
    }
    public String getIsjyyj() {
        return isjyyj;
    }

    public void setIsjyyj(String isjyyj) {
        this.isjyyj = isjyyj;
    }

    public String getUseage() {
        return useage;
    }

    public void setUseage(String useage) {
        this.useage = useage;
    }

    public Long getBeianArea() {
        return beianArea;
    }

    public void setBeianArea(Long beianArea) {
        this.beianArea = beianArea;
    }
    public Long getBjgw() {
        return bjgw;
    }

    public void setBjgw(Long bjgw) {
        this.bjgw = bjgw;
    }
    public String getIsmany() {
        return ismany;
    }

    public void setIsmany(String ismany) {
        this.ismany = ismany;
    }
    public String getIsyz() {
        return isyz;
    }

    public void setIsyz(String isyz) {
        this.isyz = isyz;
    }
    public String getIslock() {
        return islock;
    }

    public void setIslock(String islock) {
        this.islock = islock;
    }
    public String getJydate() {
        return jydate;
    }

    public void setJydate(String jydate) {
        this.jydate = jydate;
    }
    public String getPlanReturnDate() {
        return planReturnDate;
    }

    public void setPlanReturnDate(String planReturnDate) {
        this.planReturnDate = planReturnDate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getPjpsn() {
        return pjpsn;
    }

    public void setPjpsn(String pjpsn) {
        this.pjpsn = pjpsn;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}
